This is an automated email from the ASF dual-hosted git repository.

fanningpj pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/incubator-pekko-http.git


The following commit(s) were added to refs/heads/main by this push:
     new 524ca2317 fix more issues with legacy Akka naming (#155)
524ca2317 is described below

commit 524ca2317980208397f3d0dbc31a07a49b5551c2
Author: PJ Fanning <[email protected]>
AuthorDate: Fri May 26 16:10:06 2023 +0100

    fix more issues with legacy Akka naming (#155)
---
 .github/workflows/nightly.yml                          |  2 +-
 .github/workflows/validate-and-test.yml                |  4 ++--
 CONTRIBUTING.md                                        | 12 ++++++------
 build.sbt                                              |  2 +-
 docs/src/main/paradox/client-side/client-transport.md  |  2 +-
 docs/src/main/paradox/common/json-support.md           |  2 +-
 docs/src/main/paradox/common/sse-support.md            |  2 +-
 ...andling-blocking-operations-in-pekko-http-routes.md |  4 ++--
 docs/src/main/paradox/release-notes/index.md           |  2 ++
 .../routing-dsl/directives/route-directives/handle.md  |  2 +-
 .../routing-dsl/directives/route-directives/index.md   |  2 +-
 docs/src/main/paradox/routing-dsl/index.md             | 10 +++++-----
 .../javadsl/server/RejectionHandlerExamplesTest.java   |  2 +-
 .../directives/RespondWithDirectivesExamplesTest.java  |  8 ++++----
 .../docs/http/scaladsl/HttpClientExampleSpec.scala     |  4 ++--
 .../http/scaladsl/HttpServerWithActorsSample.scala     | 16 ++++++++--------
 .../scaladsl/server/RejectionHandlerExamplesSpec.scala |  4 ++--
 .../apache/pekko/http/javadsl/model/HttpMessage.java   |  2 +-
 .../http/impl/util/StageLoggingWithOverride.scala      |  4 ++--
 .../scala/org/apache/pekko/http/scaladsl/Http.scala    |  2 +-
 .../http/impl/engine/ws/WebSocketIntegrationSpec.scala |  2 +-
 .../org/apache/pekko/http/scaladsl/TestClient.scala    |  6 +++---
 .../autobahn-jenkins/step-5-server-tests-all.sh        |  8 ++++----
 .../http/scaladsl/testkit/ScalatestRouteTestSpec.scala |  4 ++--
 .../http/PekkoHttpServerLatencyMultiNodeSpec.scala     |  2 +-
 .../scala/org/scalatest/extra/QuietReporter.scala      |  2 +-
 .../directives/FileAndResourceDirectivesSpec.scala     |  2 +-
 .../org/apache/pekko/http/javadsl/server/HttpApp.java  |  2 +-
 .../apache/pekko/http/scaladsl/server/HttpApp.scala    |  2 +-
 project/Doc.scala                                      |  8 ++++----
 project/MultiNode.scala                                | 18 +++++++++---------
 31 files changed, 73 insertions(+), 71 deletions(-)

diff --git a/.github/workflows/nightly.yml b/.github/workflows/nightly.yml
index 7603d8dd4..99dfd1175 100644
--- a/.github/workflows/nightly.yml
+++ b/.github/workflows/nightly.yml
@@ -44,7 +44,7 @@ jobs:
         run: sbt -Dpekko.http.build.pekko.version=${{ matrix.PEKKO_VERSION }} 
++${{ matrix.SCALA_VERSION }} Test/compile
 
       - name: Run all tests JDK ${{ matrix.JDK }}, Scala ${{ 
matrix.SCALA_VERSION }}, Akka ${{ matrix.PEKKO_VERSION }}
-        run: sbt -Dpekko.http.parallelExecution=false -Dakka.test.timefactor=2 
-Dpekko.http.build.pekko.version=${{ matrix.PEKKO_VERSION }} ++${{ 
matrix.SCALA_VERSION }} mimaReportBinaryIssues test
+        run: sbt -Dpekko.http.parallelExecution=false 
-Dpekko.test.timefactor=2 -Dpekko.http.build.pekko.version=${{ 
matrix.PEKKO_VERSION }} ++${{ matrix.SCALA_VERSION }} mimaReportBinaryIssues 
test
 
       - name: Upload test results
         uses: actions/upload-artifact@v3  # upload test results
diff --git a/.github/workflows/validate-and-test.yml 
b/.github/workflows/validate-and-test.yml
index 228fe76af..306039039 100644
--- a/.github/workflows/validate-and-test.yml
+++ b/.github/workflows/validate-and-test.yml
@@ -88,12 +88,12 @@ jobs:
       # Quick testing for PR validation
       - name: Validate pull request for JDK ${{ matrix.JDK }}, Scala ${{ 
matrix.SCALA_VERSION }}
         if: ${{ github.event_name == 'pull_request' }}
-        run: sbt -Dpekko.http.parallelExecution=false -Dakka.test.timefactor=2 
++${{ matrix.SCALA_VERSION }} validatePullRequest
+        run: sbt -Dpekko.http.parallelExecution=false 
-Dpekko.test.timefactor=2 ++${{ matrix.SCALA_VERSION }} validatePullRequest
 
       # Full testing for pushes
       - name: Run all tests JDK ${{ matrix.JDK }}, Scala ${{ 
matrix.SCALA_VERSION }}
         if: ${{ github.event_name == 'push' }}
-        run: sbt -Dpekko.http.parallelExecution=false -Dakka.test.timefactor=2 
++${{ matrix.SCALA_VERSION }} mimaReportBinaryIssues test
+        run: sbt -Dpekko.http.parallelExecution=false 
-Dpekko.test.timefactor=2 ++${{ matrix.SCALA_VERSION }} mimaReportBinaryIssues 
test
 
       - name: Upload test results
         uses: actions/upload-artifact@v3  # upload test results
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 43ae59352..b181a0232 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -127,13 +127,13 @@ Pekko HTTP codebase is currently built with snapshot 
versions of the Pekko core
 
 Since Pekko HTTP is released separately to Pekko "core", yet some features 
require changes in Pekko itself, it is sometimes very useful
 to be able to develop Pekko HTTP with Pekko's sources used directly instead of 
the binary dependency. You can check out the Pekko 
-repository and run sbt with `-Dpekko.sources=$HOME/akka` to develop Pekko HTTP 
with Pekko as a source dependency instead of a binary one.
+repository and run sbt with `-Dpekko.sources=$HOME/pekko` to develop Pekko 
HTTP with Pekko as a source dependency instead of a binary one.
 
 This allows simple and fast iterations on changes that would need to be 
introduced in Pekko to develop a feature in HTTP that would require those.
 
 ## Binary compatibility
 Binary compatibility rules and guarantees are described in depth in the 
[Binary Compatibility Rules
-](https://doc.akka.io/docs/akka/current/common/binary-compatibility-rules.html)
 section of the documentation.
+](https://pekko.apache.org/docs/pekko/current/common/binary-compatibility-rules.html)
 section of the documentation.
 
 Pekko HTTP uses MiMa (which is short for [Lightbend Migration 
Manager](https://github.com/lightbend/migration-manager)) to
 validate binary compatibility of incoming Pull Requests. If your PR fails due 
to binary compatibility issues, you may see 
@@ -153,7 +153,7 @@ Situations where it may be fine to ignore a MiMa issued 
warning include:
 - if it is touching any class marked as `private[pekko]`, `/** INTERNAL API*/` 
or similar markers
 - if it is concerning internal classes (often recognizable by package names 
like `dungeon`, `impl`, `internal` etc.)
 - if it is adding API to classes / traits which are only meant for extension 
by Pekko itself, i.e. should not be extended by end-users
-- if it is touching any class marked with the `@InternalApi`, `@DoNotInherit`, 
and `@ApiMayChange`. See [API stability annotations and 
comments](https://doc.akka.io/docs/akka/current/common/binary-compatibility-rules.html#api-stability-annotations-and-comments)
+- if it is touching any class marked with the `@InternalApi`, `@DoNotInherit`, 
and `@ApiMayChange`. See [API stability annotations and 
comments](https://pekko.apache.org/docs/pekko/current/common/binary-compatibility-rules.html#api-stability-annotations-and-comments)
 - other tricky situations
 
 If it turns out that the change can be safely ignored, please add the filter 
to a file with the issue number in the filename, placed in the submodule's 
`src/main/mima-filters/<last-released-version>.backwards.excludes` directory.
@@ -317,7 +317,7 @@ There is a number of ways timeouts can be defined in Pekko 
tests. The following
 
 Special care should be given `expectNoMessage` calls, which indeed will wait 
the entire timeout before continuing, therefore a shorter timeout should be 
used in those, for example `200` or `300.millis`.
 
-You can read up on remaining and friends in 
[TestKit.scala](https://github.com/apache/incubator-pekko/blob/main/akka-testkit/src/main/scala/org/apache/pekko/testkit/TestKit.scala)
+You can read up on remaining and friends in 
[TestKit.scala](https://github.com/apache/incubator-pekko/blob/main/pekko-testkit/src/main/scala/org/apache/pekko/testkit/TestKit.scala)
 
 # Supporting infrastructure
 
@@ -346,8 +346,8 @@ A great tool to inspect HTTP/2 frames of real-world 
connections is
 
 When analyzing an HTTPS connection, you need a way to see the plaintext
 payloads. You can enable logging those on the Pekko HTTP side with
-`akka.http.server.log-unencrypted-network-bytes = 100` or
-`akka.http.server.http2.log-frames = true` (same for client-side).
+`pekko.http.server.log-unencrypted-network-bytes = 100` or
+`pekko.http.server.http2.log-frames = true` (same for client-side).
 
 To see the traffic in Wireshark, some clients can be configured to dump an
 `SSLKEYLOGFILE` that Wireshark
diff --git a/build.sbt b/build.sbt
index 8b54001d2..8c0fe783d 100644
--- a/build.sbt
+++ b/build.sbt
@@ -441,7 +441,7 @@ lazy val compatibilityTests = 
Project("http-compatibility-tests", file("http-com
     (Test / dependencyClasspath) := {
       // HACK: We'd like to use `dependsOn(http % "test->compile")` to upgrade 
the explicit dependency above to the
       //       current version but that fails. So, this is a manual 
`dependsOn` which works as expected.
-      (Test / dependencyClasspath).value.filterNot(_.data.getName contains 
"akka") ++
+      (Test / dependencyClasspath).value.filterNot(_.data.getName contains 
"pekko") ++
       (httpTests / Test / fullClasspath).value
     }
   )
diff --git a/docs/src/main/paradox/client-side/client-transport.md 
b/docs/src/main/paradox/client-side/client-transport.md
index a6d11193c..54b572231 100644
--- a/docs/src/main/paradox/client-side/client-transport.md
+++ b/docs/src/main/paradox/client-side/client-transport.md
@@ -109,7 +109,7 @@ Java
 You can use @apidoc[ClientTransport.withCustomResolver](ClientTransport) to 
customize host name resolution. The given resolution function will be called 
for every connection attempt to resolve
 a hostname / port combination (potentially asynchronously) to an 
`InetSocketAddress`.
 
-As a backend to implement the resolution function you can use Apache Pekko's 
[Async DNS 
Resolution](https://doc.akka.io/docs/akka/current/io-dns.html#dns-extension).
+As a backend to implement the resolution function you can use Apache Pekko's 
[Async DNS 
Resolution](https://pekko.apache.org/docs/pekko/current/io-dns.html#dns-extension).
 
 Potential use cases:
 
diff --git a/docs/src/main/paradox/common/json-support.md 
b/docs/src/main/paradox/common/json-support.md
index c28bebe9d..f3ab1bf83 100644
--- a/docs/src/main/paradox/common/json-support.md
+++ b/docs/src/main/paradox/common/json-support.md
@@ -3,7 +3,7 @@
 Apache Pekko HTTP's @ref[marshalling](marshalling.md) and 
@ref[unmarshalling](unmarshalling.md) infrastructure makes it rather easy to 
seamlessly convert application-domain objects from and to JSON.
 Integration with @scala[[spray-json]]@java[[Jackson]] is provided out of the 
box through the @scala[`pekko-http-spray-json`]@java[`pekko-http-jackson`] 
module.
 Integration with other JSON libraries are supported by the community.
-See [the list of current community extensions for Apache Pekko 
HTTP](https://akka.io/community/#extensions-to-akka-http).
+See @ref[the list of current community extensions for Apache Pekko 
HTTP](../examples-and-extensions.md#extensions).
 
 @@@ div { .group-java }
 
diff --git a/docs/src/main/paradox/common/sse-support.md 
b/docs/src/main/paradox/common/sse-support.md
index 6f2ac727e..081222067 100644
--- a/docs/src/main/paradox/common/sse-support.md
+++ b/docs/src/main/paradox/common/sse-support.md
@@ -57,5 +57,5 @@ Java
 :  @@snip 
[EventStreamMarshallingTest.java](/http-tests/src/test/java/org/apache/pekko/http/javadsl/unmarshalling/sse/EventStreamUnmarshallingTest.java)
 { #event-stream-unmarshalling-example }
 
 Notice that if you are looking for a resilient way to permanently subscribe to 
an event stream,
-Apache Pekko Connectors provides the 
[EventSource](https://doc.akka.io/docs/alpakka/current/sse.html)
+Apache Pekko Connectors provides the 
[EventSource](https://pekko.apache.org/docs/pekko-connectors/current/sse.html)
 connector which reconnects automatically with the id of the last seen event.
diff --git 
a/docs/src/main/paradox/handling-blocking-operations-in-pekko-http-routes.md 
b/docs/src/main/paradox/handling-blocking-operations-in-pekko-http-routes.md
index 780ba2788..0c552c91f 100644
--- a/docs/src/main/paradox/handling-blocking-operations-in-pekko-http-routes.md
+++ b/docs/src/main/paradox/handling-blocking-operations-in-pekko-http-routes.md
@@ -63,8 +63,8 @@ provided dispatcher would be used. Both these dispatchers are 
ForkJoin pools by
 not best suited for blocking operations.
 @@@
 For example, the above screenshot shows an Apache Pekko FJP dispatchers 
threads,
-named "`default-akka.default-dispatcher2,3,4`" going into the blocking state, 
after having been idle. 
-It can be observed that the number of new threads increases, 
"`default-akka.actor.default-dispatcher 18,19,20,...`" 
+named "`default-pekko.default-dispatcher2,3,4`" going into the blocking state, 
after having been idle. 
+It can be observed that the number of new threads increases, 
"`default-pekko.actor.default-dispatcher 18,19,20,...`" 
 however they go to sleep state immediately, thus wasting the resources.
 @java[The same happens to the global 
@javadoc[ForkJoinPool](java.util.concurrent.ForkJoinPool) when using Java 
Futures.]
 
diff --git a/docs/src/main/paradox/release-notes/index.md 
b/docs/src/main/paradox/release-notes/index.md
index b9292fd49..106ccdbe3 100644
--- a/docs/src/main/paradox/release-notes/index.md
+++ b/docs/src/main/paradox/release-notes/index.md
@@ -1,5 +1,7 @@
 # 0. Release Notes
 
+There are no Apache Pekko HTTP releases yet.
+
 @@toc { depth=2 }
 
 * [Akka HTTP 
releases](https://doc.akka.io/docs/akka-http/10.2/release-notes/index.html)
diff --git 
a/docs/src/main/paradox/routing-dsl/directives/route-directives/handle.md 
b/docs/src/main/paradox/routing-dsl/directives/route-directives/handle.md
index f8d2bf223..1c7bfccfb 100644
--- a/docs/src/main/paradox/routing-dsl/directives/route-directives/handle.md
+++ b/docs/src/main/paradox/routing-dsl/directives/route-directives/handle.md
@@ -14,7 +14,7 @@ Creates a 
@scala[@scaladoc[Route](org.apache.pekko.http.scaladsl.server.index#Ro
 that handles the request using a function or `PartialFunction` from 
@apidoc[HttpRequest] to a @scala[`Future`]@java[`CompletionStage`] of 
@apidoc[HttpResponse].
 
 This directive can be used to include external components request processing 
components defined as a `Function` or `PartialFunction`
-(like [those provided by 
akka-grpc](https://doc.akka.io/docs/akka-grpc/current/server/walkthrough.html#serving-multiple-services))
+(like [those provided by 
pekko-grpc](https://pekko.apache.org/docs/pekko-grpc/current/server/walkthrough.html#serving-multiple-services))
 into a routing tree defined by directives and routes.
 
 For the `PartialFunction` variant, the given list of rejections will be used 
to reject the request with if the `PartialFunction` is not defined for a 
request. By default,
diff --git 
a/docs/src/main/paradox/routing-dsl/directives/route-directives/index.md 
b/docs/src/main/paradox/routing-dsl/directives/route-directives/index.md
index a7d89747d..968461fa6 100644
--- a/docs/src/main/paradox/routing-dsl/directives/route-directives/index.md
+++ b/docs/src/main/paradox/routing-dsl/directives/route-directives/index.md
@@ -1,6 +1,6 @@
 # RouteDirectives
 
-The @apidoc[RouteDirectives] have a special role in akka-http's routing DSL. 
Contrary to all other directives (except most
+The @apidoc[RouteDirectives] have a special role in pekko-http's routing DSL. 
Contrary to all other directives (except most
 @ref[FileAndResourceDirectives](../file-and-resource-directives/index.md)) 
they do not produce instances of type `Directive[L <: HList]` but rather "plain"
 routes of type 
@scala[@scaladoc[Route](org.apache.pekko.http.scaladsl.server.index#Route=org.apache.pekko.http.scaladsl.server.RequestContext=%3Escala.concurrent.Future[org.apache.pekko.http.scaladsl.server.RouteResult])]@java[@javadoc[Route](org.apache.pekko.http.javadsl.server.Route)].
 The reason is that the @apidoc[RouteDirectives] are not meant for wrapping an 
inner route (like most other directives, as
diff --git a/docs/src/main/paradox/routing-dsl/index.md 
b/docs/src/main/paradox/routing-dsl/index.md
index 07fabc43f..eed402344 100644
--- a/docs/src/main/paradox/routing-dsl/index.md
+++ b/docs/src/main/paradox/routing-dsl/index.md
@@ -61,7 +61,7 @@ The project template in @scala[[Apache Pekko HTTP Quickstart 
for Scala](https://
 
 If you have been using Play framework's routes file notation before this 
@ref[Play comparison](play-comparison.md) may help you to get started with 
Apache Pekko HTTP routing.
 
-<a name="interaction-with-akka-typed">
+<a name="interaction-with-pekko-typed">
 ## Interaction with Actors
 
 The following example shows how to use Apache Pekko HTTP with Apache Pekko 
Actors.
@@ -73,7 +73,7 @@ First let's start by defining the @apidoc[Behavior] that will 
act as a repositor
 strictly needed for our sample, but just to have an actual actor to interact 
with:
 
 Scala
-:  @@snip 
[HttpServerWithActorsSample.scala](/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala)
 { #akka-typed-behavior }
+:  @@snip 
[HttpServerWithActorsSample.scala](/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala)
 { #pekko-typed-behavior }
 
 Java
 :  @@snip 
[JobRepository.scala](/docs/src/test/java/docs/http/javadsl/JobRepository.java) 
{ #behavior }
@@ -83,7 +83,7 @@ Java
 Then, let's define the JSON marshaller and unmarshallers for the HTTP routes:
 
 Scala
-:  @@snip 
[HttpServerWithActorsSample.scala](/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala)
 { #akka-typed-json }
+:  @@snip 
[HttpServerWithActorsSample.scala](/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala)
 { #pekko-typed-json }
 
 @@@
 
@@ -94,7 +94,7 @@ that will communicate with the previously defined behavior
 and handle all its possible responses:
 
 Scala
-:  @@snip 
[HttpServerWithActorsSample.scala](/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala)
 { #akka-typed-route }
+:  @@snip 
[HttpServerWithActorsSample.scala](/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala)
 { #pekko-typed-route }
 
 Java
 :  @@snip 
[JobRoutes.scala](/docs/src/test/java/docs/http/javadsl/JobRoutes.java) { 
#route }
@@ -102,7 +102,7 @@ Java
 Finally, we create a @apidoc[Behavior] that bootstraps the web server and use 
it as the root behavior of our actor system:
 
 Scala
-:  @@snip 
[HttpServerWithActorsSample.scala](/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala)
 { #akka-typed-bootstrap }
+:  @@snip 
[HttpServerWithActorsSample.scala](/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala)
 { #pekko-typed-bootstrap }
 
 Java
 :  @@snip 
[HttpServerWithActorsSample.java](/docs/src/test/java/docs/http/javadsl/HttpServerWithActorsSample.java)
 { #bootstrap }
diff --git 
a/docs/src/test/java/docs/http/javadsl/server/RejectionHandlerExamplesTest.java 
b/docs/src/test/java/docs/http/javadsl/server/RejectionHandlerExamplesTest.java
index 30b2a0247..7fa3fdd45 100644
--- 
a/docs/src/test/java/docs/http/javadsl/server/RejectionHandlerExamplesTest.java
+++ 
b/docs/src/test/java/docs/http/javadsl/server/RejectionHandlerExamplesTest.java
@@ -118,7 +118,7 @@ public class RejectionHandlerExamplesTest extends 
JUnitRouteTest {
             .mapRejectionResponse(
                 response -> {
                   if (response.entity() instanceof HttpEntity.Strict) {
-                    // since all Akka default rejection responses are Strict 
this will handle all
+                    // since all Pekko default rejection responses are Strict 
this will handle all
                     // rejections
                     String message =
                         ((HttpEntity.Strict) response.entity())
diff --git 
a/docs/src/test/java/docs/http/javadsl/server/directives/RespondWithDirectivesExamplesTest.java
 
b/docs/src/test/java/docs/http/javadsl/server/directives/RespondWithDirectivesExamplesTest.java
index 4bcb6e5d1..fac175a73 100644
--- 
a/docs/src/test/java/docs/http/javadsl/server/directives/RespondWithDirectivesExamplesTest.java
+++ 
b/docs/src/test/java/docs/http/javadsl/server/directives/RespondWithDirectivesExamplesTest.java
@@ -148,10 +148,10 @@ public class RespondWithDirectivesExamplesTest extends 
JUnitRouteTest {
   public void testRespondWithHeaders() {
     // #respondWithHeaders
     final HttpHeader gonzo = RawHeader.create("Funky-Muppet", "gonzo");
-    final HttpHeader akka = 
Origin.create(HttpOrigin.parse("http://pekko.apache.org";));
+    final HttpHeader pekko = 
Origin.create(HttpOrigin.parse("http://pekko.apache.org";));
 
     final Route route =
-        path("foo", () -> respondWithHeaders(Arrays.asList(gonzo, akka), () -> 
complete("beep")));
+        path("foo", () -> respondWithHeaders(Arrays.asList(gonzo, pekko), () 
-> complete("beep")));
 
     testRoute(route)
         .run(HttpRequest.GET("/foo"))
@@ -167,8 +167,8 @@ public class RespondWithDirectivesExamplesTest extends 
JUnitRouteTest {
     // #respondWithDefaultHeaders
     // custom headers
     final RawHeader blippy = RawHeader.create("X-Fish-Name", "Blippy");
-    final HttpHeader akka = 
Origin.create(HttpOrigin.parse("http://pekko.apache.org";));
-    final List<HttpHeader> defaultHeaders = Arrays.asList(blippy, akka);
+    final HttpHeader pekko = 
Origin.create(HttpOrigin.parse("http://pekko.apache.org";));
+    final List<HttpHeader> defaultHeaders = Arrays.asList(blippy, pekko);
     final RawHeader elTonno = RawHeader.create("X-Fish-Name", "El Tonno");
 
     // format: OFF
diff --git a/docs/src/test/scala/docs/http/scaladsl/HttpClientExampleSpec.scala 
b/docs/src/test/scala/docs/http/scaladsl/HttpClientExampleSpec.scala
index 418a3b562..28ef69e58 100644
--- a/docs/src/test/scala/docs/http/scaladsl/HttpClientExampleSpec.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/HttpClientExampleSpec.scala
@@ -117,7 +117,7 @@ class HttpClientExampleSpec extends AnyWordSpec with 
Matchers with CompileOnlySp
     val processorFlow: Flow[Option[ExamplePerson], Int, NotUsed] =
       Flow[Option[ExamplePerson]].map(_.map(_.name.length).getOrElse(0))
 
-    // Run and completely consume a single akka http request
+    // Run and completely consume a single pekko http request
     def runRequest(req: HttpRequest): Future[Option[ExamplePerson]] =
       Http()
         .singleRequest(req)
@@ -127,7 +127,7 @@ class HttpClientExampleSpec extends AnyWordSpec with 
Matchers with CompileOnlySp
             .map(parse)
         }
 
-    // Run each akka http flow to completion, then continue processing. You'll 
want to tune the `parallelism`
+    // Run each pekko http flow to completion, then continue processing. 
You'll want to tune the `parallelism`
     // parameter to mapAsync -- higher values will create more cpu and memory 
load which may or may not positively
     // impact performance.
     requests
diff --git 
a/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala 
b/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala
index 4cb864d1b..26f5e238f 100644
--- a/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala
+++ b/docs/src/test/scala/docs/http/scaladsl/HttpServerWithActorsSample.scala
@@ -15,7 +15,7 @@ package docs.http.scaladsl
 
 object HttpServerWithActorsSample {
 
-  // #akka-typed-behavior
+  // #pekko-typed-behavior
   import org.apache.pekko
   import pekko.actor.typed.{ ActorRef, Behavior }
   import pekko.actor.typed.scaladsl.Behaviors
@@ -57,9 +57,9 @@ object HttpServerWithActorsSample {
     }
 
   }
-  // #akka-typed-behavior
+  // #pekko-typed-behavior
 
-  // #akka-typed-json
+  // #pekko-typed-json
   import org.apache.pekko.http.scaladsl.marshallers.sprayjson.SprayJsonSupport
   import spray.json.DefaultJsonProtocol
   import spray.json.DeserializationException
@@ -88,9 +88,9 @@ object HttpServerWithActorsSample {
 
     implicit val jobFormat: RootJsonFormat[Job] = jsonFormat4(Job.apply)
   }
-  // #akka-typed-json
+  // #pekko-typed-json
 
-  // #akka-typed-route
+  // #pekko-typed-route
   import org.apache.pekko
   import pekko.actor.typed.ActorSystem
   import pekko.util.Timeout
@@ -145,9 +145,9 @@ object HttpServerWithActorsSample {
           })
       }
   }
-  // #akka-typed-route
+  // #pekko-typed-route
 
-  // #akka-typed-bootstrap
+  // #pekko-typed-bootstrap
   import org.apache.pekko
   import pekko.actor.typed.PostStop
   import pekko.http.scaladsl.Http.ServerBinding
@@ -214,5 +214,5 @@ object HttpServerWithActorsSample {
     val system: ActorSystem[Server.Message] =
       ActorSystem(Server("localhost", 8080), "BuildJobsServer")
   }
-  // #akka-typed-bootstrap
+  // #pekko-typed-bootstrap
 }
diff --git 
a/docs/src/test/scala/docs/http/scaladsl/server/RejectionHandlerExamplesSpec.scala
 
b/docs/src/test/scala/docs/http/scaladsl/server/RejectionHandlerExamplesSpec.scala
index b23e58d5b..1baeb7782 100644
--- 
a/docs/src/test/scala/docs/http/scaladsl/server/RejectionHandlerExamplesSpec.scala
+++ 
b/docs/src/test/scala/docs/http/scaladsl/server/RejectionHandlerExamplesSpec.scala
@@ -114,7 +114,7 @@ class RejectionHandlerExamplesSpec extends RoutingSpec with 
CompileOnlySpec {
       RejectionHandler.default
         .mapRejectionResponse {
           case res @ HttpResponse(_, _, ent: HttpEntity.Strict, _) =>
-            // since all Akka default rejection responses are Strict this will 
handle all rejections
+            // since all Pekko default rejection responses are Strict this 
will handle all rejections
             val message = ent.data.utf8String.replaceAll("\"", """\"""")
 
             // we copy the response in order to keep all headers and status 
code, wrapping the message as hand rolled JSON
@@ -147,7 +147,7 @@ class RejectionHandlerExamplesSpec extends RoutingSpec with 
CompileOnlySpec {
       RejectionHandler.default
         .mapRejectionResponse {
           case res @ HttpResponse(_, _, ent: HttpEntity.Strict, _) =>
-            // since all Akka default rejection responses are Strict this will 
handle all rejections
+            // since all Pekko default rejection responses are Strict this 
will handle all rejections
             val message = ent.data.utf8String.replaceAll("\"", """\"""")
 
             // we copy the response in order to keep all headers and status 
code, wrapping the message as hand rolled JSON
diff --git 
a/http-core/src/main/java/org/apache/pekko/http/javadsl/model/HttpMessage.java 
b/http-core/src/main/java/org/apache/pekko/http/javadsl/model/HttpMessage.java
index 9a3c32d70..0a963eeac 100644
--- 
a/http-core/src/main/java/org/apache/pekko/http/javadsl/model/HttpMessage.java
+++ 
b/http-core/src/main/java/org/apache/pekko/http/javadsl/model/HttpMessage.java
@@ -31,7 +31,7 @@ import java.util.concurrent.Executor;
  * The base type for an Http message (request or response).
  *
  * <p>INTERNAL API: this trait will be changed in binary-incompatible ways for 
classes that are
- * derived from it! Do not implement this interface outside the Akka code base!
+ * derived from it! Do not implement this interface outside the Pekko code 
base!
  *
  * <p>Binary compatibility is only maintained for callers of this trait’s 
interface.
  */
diff --git 
a/http-core/src/main/scala/org/apache/pekko/http/impl/util/StageLoggingWithOverride.scala
 
b/http-core/src/main/scala/org/apache/pekko/http/impl/util/StageLoggingWithOverride.scala
index 15879a27b..9826ff324 100644
--- 
a/http-core/src/main/scala/org/apache/pekko/http/impl/util/StageLoggingWithOverride.scala
+++ 
b/http-core/src/main/scala/org/apache/pekko/http/impl/util/StageLoggingWithOverride.scala
@@ -10,7 +10,7 @@
 /*
  * Copyright (C) 2017-2022 Lightbend Inc. <https://www.lightbend.com>
  *
- * Copied and adapted from akka-remote
+ * Copied and adapted from pekko-remote
  * 
https://github.com/akka/akka/blob/c90121485fcfc44a3cee62a0c638e1982d13d812/akka-remote/src/main/scala/akka/remote/artery/StageLogging.scala
  */
 
@@ -22,7 +22,7 @@ import pekko.stream.stage.GraphStageLogic
 import pekko.event.{ LogSource, LoggingAdapter, NoLogging }
 import pekko.stream.ActorMaterializer
 
-// TODO Try to reconcile with what Akka provides in StageLogging.
+// TODO Try to reconcile with what Pekko provides in StageLogging.
 // We thought this could be removed when 
https://github.com/akka/akka/issues/18793 had been implemented
 // but we need a few more changes to be able to override the default logger. 
So for now we keep it here.
 /**
diff --git a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/Http.scala 
b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/Http.scala
index 75236b3e7..980ac759b 100644
--- a/http-core/src/main/scala/org/apache/pekko/http/scaladsl/Http.scala
+++ b/http-core/src/main/scala/org/apache/pekko/http/scaladsl/Http.scala
@@ -59,7 +59,7 @@ import scala.concurrent.duration.{ Duration, FiniteDuration }
 import scala.concurrent.duration._
 
 /**
- * Akka extension for HTTP which serves as the main entry point into 
pekko-http.
+ * Pekko extension for HTTP which serves as the main entry point into 
pekko-http.
  *
  * Use as `Http().bindAndHandle` etc. with an implicit [[ActorSystem]] in 
scope.
  */
diff --git 
a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/ws/WebSocketIntegrationSpec.scala
 
b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/ws/WebSocketIntegrationSpec.scala
index a4fce95a2..072e0674f 100644
--- 
a/http-core/src/test/scala/org/apache/pekko/http/impl/engine/ws/WebSocketIntegrationSpec.scala
+++ 
b/http-core/src/test/scala/org/apache/pekko/http/impl/engine/ws/WebSocketIntegrationSpec.scala
@@ -39,7 +39,7 @@ import scala.util.{ Failure, Success }
 
 class WebSocketIntegrationSpec extends PekkoSpecWithMaterializer(
       """
-     akka {
+     pekko {
        stream.materializer.debug.fuzzing-mode=off
        http.server.websocket.log-frames = on
        http.client.websocket.log-frames = on
diff --git 
a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/TestClient.scala 
b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/TestClient.scala
index 3f9fe6adb..9b0e7c6ec 100644
--- a/http-core/src/test/scala/org/apache/pekko/http/scaladsl/TestClient.scala
+++ b/http-core/src/test/scala/org/apache/pekko/http/scaladsl/TestClient.scala
@@ -80,7 +80,7 @@ object TestClient extends App {
     }
   }
 
-  // for gathering dumps of entity and headers from akka http client
+  // for gathering dumps of entity and headers from pekko http client
   // and curl in parallel to compare
   def fetchAndStoreABunchOfUrlsWithHttpAndCurl(urls: Seq[String]): Unit = {
     assert(urls.nonEmpty)
@@ -96,8 +96,8 @@ object TestClient extends App {
       val done = Future.traverse(urls.zipWithIndex) {
         case (url, index) =>
           Http().singleRequest(HttpRequest(uri = url)).map { response =>
-            val path = new 
File(s"/tmp/client-dumps/akka-body-$index.dump").toPath
-            val headersPath = new 
File(s"/tmp/client-dumps/akka-headers-$index.dump").toPath
+            val path = new 
File(s"/tmp/client-dumps/pekko-body-$index.dump").toPath
+            val headersPath = new 
File(s"/tmp/client-dumps/pekko-headers-$index.dump").toPath
 
             import scala.sys.process._
             (s"""curl -D /tmp/client-dumps/curl-headers-$index.dump $url""" #> 
new File(
diff --git 
a/http-testkit/src/test/scala/org/apache/pekko/http/scaladsl/testkit/ScalatestRouteTestSpec.scala
 
b/http-testkit/src/test/scala/org/apache/pekko/http/scaladsl/testkit/ScalatestRouteTestSpec.scala
index 2a7c43118..5017567f8 100644
--- 
a/http-testkit/src/test/scala/org/apache/pekko/http/scaladsl/testkit/ScalatestRouteTestSpec.scala
+++ 
b/http-testkit/src/test/scala/org/apache/pekko/http/scaladsl/testkit/ScalatestRouteTestSpec.scala
@@ -97,10 +97,10 @@ class ScalatestRouteTestSpec extends AnyFreeSpec with 
Matchers with ScalatestRou
       }
     }
 
-    "running on akka dispatcher threads" in Await.result(Future {
+    "running on pekko dispatcher threads" in Await.result(Future {
         // https://github.com/apache/incubator-pekko-http/pull/2526
         // Check will block while waiting on the response, this might lead to 
starvation
-        // on the BatchingExecutor of akka's dispatcher if the blocking is not 
managed properly.
+        // on the BatchingExecutor of pekko's dispatcher if the blocking is 
not managed properly.
         Get() ~> complete(Future(HttpResponse())) ~> check {
           status shouldEqual OK
         }
diff --git 
a/http-tests/src/multi-jvm/scala/org/apache/pekko/http/PekkoHttpServerLatencyMultiNodeSpec.scala
 
b/http-tests/src/multi-jvm/scala/org/apache/pekko/http/PekkoHttpServerLatencyMultiNodeSpec.scala
index 45ba21085..acded81b3 100644
--- 
a/http-tests/src/multi-jvm/scala/org/apache/pekko/http/PekkoHttpServerLatencyMultiNodeSpec.scala
+++ 
b/http-tests/src/multi-jvm/scala/org/apache/pekko/http/PekkoHttpServerLatencyMultiNodeSpec.scala
@@ -38,7 +38,7 @@ object PekkoHttpServerLatencyMultiNodeSpec extends 
MultiNodeConfig {
 
   commonConfig(ConfigFactory.parseString(
     """
-      akka {
+      pekko {
         actor.default-mailbox.mailbox-type = 
"org.apache.pekko.dispatch.UnboundedMailbox"
         actor.provider = "org.apache.pekko.remote.RemoteActorRefProvider"
         actor.warn-about-java-serializer-usage = off
diff --git 
a/http-tests/src/multi-jvm/scala/org/scalatest/extra/QuietReporter.scala 
b/http-tests/src/multi-jvm/scala/org/scalatest/extra/QuietReporter.scala
index 52fd4eea2..8e339392f 100644
--- a/http-tests/src/multi-jvm/scala/org/scalatest/extra/QuietReporter.scala
+++ b/http-tests/src/multi-jvm/scala/org/scalatest/extra/QuietReporter.scala
@@ -21,7 +21,7 @@ class QuietReporter(inColor: Boolean, withDurations: Boolean 
= false)
     extends StandardOutReporter(withDurations, inColor, false, true, false, 
false, false, false, false, false,
       presentJson = false) {
 
-  def this() = this(!getBoolean("akka.test.nocolor"), 
!getBoolean("akka.test.nodurations"))
+  def this() = this(!getBoolean("pekko.test.nocolor"), 
!getBoolean("pekko.test.nodurations"))
 
   override def apply(event: Event): Unit = event match {
     case _: RunStarting => ()
diff --git 
a/http-tests/src/test/scala/org/apache/pekko/http/scaladsl/server/directives/FileAndResourceDirectivesSpec.scala
 
b/http-tests/src/test/scala/org/apache/pekko/http/scaladsl/server/directives/FileAndResourceDirectivesSpec.scala
index 3e9f62bb7..ea94c66e3 100644
--- 
a/http-tests/src/test/scala/org/apache/pekko/http/scaladsl/server/directives/FileAndResourceDirectivesSpec.scala
+++ 
b/http-tests/src/test/scala/org/apache/pekko/http/scaladsl/server/directives/FileAndResourceDirectivesSpec.scala
@@ -58,7 +58,7 @@ class FileAndResourceDirectivesSpec extends RoutingSpec with 
Inspectors with Ins
       Get() ~> getFromFile(Properties.javaHome) ~> check { handled shouldEqual 
false }
     }
     "return the file content with the MediaType matching the file extension" 
in {
-      val file = File.createTempFile("akka Http Test", ".PDF")
+      val file = File.createTempFile("pekko Http Test", ".PDF")
       try {
         writeAllText("This is PDF", file)
         Get() ~> getFromFile(file.getPath) ~> check {
diff --git 
a/http/src/main/java/org/apache/pekko/http/javadsl/server/HttpApp.java 
b/http/src/main/java/org/apache/pekko/http/javadsl/server/HttpApp.java
index 11ae6a34a..3596ea7fd 100644
--- a/http/src/main/java/org/apache/pekko/http/javadsl/server/HttpApp.java
+++ b/http/src/main/java/org/apache/pekko/http/javadsl/server/HttpApp.java
@@ -31,7 +31,7 @@ import java.util.concurrent.ExecutionException;
 import java.util.concurrent.atomic.AtomicReference;
 
 /**
- * DEPRECATED, consider 
https://developer.lightbend.com/guides/akka-http-quickstart-java/ instead
+ * DEPRECATED, consider 
https://github.com/theiterators/pekko-http-quickstart-java.g8 instead
  *
  * <p>Bootstrap trait for Http Server. It helps booting up an pekko-http 
server by only defining the
  * desired routes. It offers additional hooks to modify the default behavior.
diff --git 
a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/HttpApp.scala 
b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/HttpApp.scala
index 23730ad48..53004798d 100644
--- a/http/src/main/scala/org/apache/pekko/http/scaladsl/server/HttpApp.scala
+++ b/http/src/main/scala/org/apache/pekko/http/scaladsl/server/HttpApp.scala
@@ -30,7 +30,7 @@ import scala.io.StdIn
 import scala.util.{ Failure, Success, Try }
 
 /**
- * DEPRECATED, consider 
https://developer.lightbend.com/guides/akka-http-quickstart-scala/ instead
+ * DEPRECATED, consider 
https://github.com/theiterators/pekko-http-quickstart-scala.g8 instead
  *
  * Bootstrap trait for Http Server. It helps booting up an pekko-http server 
by only defining the desired routes.
  * It offers additional hooks to modify the default behavior.
diff --git a/project/Doc.scala b/project/Doc.scala
index 4c7f9287e..f942d33e4 100644
--- a/project/Doc.scala
+++ b/project/Doc.scala
@@ -30,8 +30,8 @@ object Doc {
 object Scaladoc extends AutoPlugin {
 
   object CliOptions {
-    val scaladocDiagramsEnabled = CliOption("akka.scaladoc.diagrams", true)
-    val scaladocAutoAPI = CliOption("akka.scaladoc.autoapi", true)
+    val scaladocDiagramsEnabled = CliOption("pekko.scaladoc.diagrams", true)
+    val scaladocAutoAPI = CliOption("pekko.scaladoc.autoapi", true)
   }
 
   override def trigger = allRequirements
@@ -152,7 +152,7 @@ object UnidocRoot extends AutoPlugin {
   override def requires =
     ScalaUnidocPlugin && 
CliOptions.genjavadocEnabled.ifTrue(JavaUnidocPlugin).getOrElse(plugins.JvmPlugin)
 
-  val akkaSettings = UnidocRoot.CliOptions.genjavadocEnabled.ifTrue(Seq(
+  val pekkoSettings = UnidocRoot.CliOptions.genjavadocEnabled.ifTrue(Seq(
     JavaUnidoc / unidoc / javacOptions ++= (
       if (isJdk8) Seq("-Xdoclint:none")
       else Seq("-Xdoclint:none", "--ignore-source-errors")),
@@ -169,7 +169,7 @@ object UnidocRoot extends AutoPlugin {
 
   override lazy val projectSettings =
     settings ++
-    akkaSettings
+    pekkoSettings
 }
 
 /**
diff --git a/project/MultiNode.scala b/project/MultiNode.scala
index c23158c9f..8aa51c1ed 100644
--- a/project/MultiNode.scala
+++ b/project/MultiNode.scala
@@ -21,13 +21,13 @@ import sbt.Keys._
 object MultiNode extends AutoPlugin {
 
   object CliOptions {
-    val multiNode = CliOption("akka.test.multi-node", false)
+    val multiNode = CliOption("pekko.test.multi-node", false)
     val sbtLogNoFormat = CliOption("sbt.log.noformat", false)
 
     def seqWithProperty(name: String) = Option(System.getProperty(name)).toSeq
-    val hostsFileName = seqWithProperty("akka.test.multi-node.hostsFileName")
-    val javaName = seqWithProperty("akka.test.multi-node.java")
-    val targetDirName = seqWithProperty("akka.test.multi-node.targetDirName")
+    val hostsFileName = seqWithProperty("pekko.test.multi-node.hostsFileName")
+    val javaName = seqWithProperty("pekko.test.multi-node.java")
+    val targetDirName = seqWithProperty("pekko.test.multi-node.targetDirName")
   }
 
   val multiExecuteTests =
@@ -44,10 +44,10 @@ object MultiNode extends AutoPlugin {
     // multinode.D= and multinode.X= makes it possible to pass arbitrary
     // -D or -X arguments to the forked jvm, e.g.
     // -Dmultinode.Djava.net.preferIPv4Stack=true -Dmultinode.Xmx512m 
-Dmultinode.XX:MaxPermSize=256M
-    // -DMultiJvm.akka.cluster.Stress.nrOfNodes=15
+    // -DMultiJvm.pekko.cluster.Stress.nrOfNodes=15
     val MultinodeJvmArgs = "multinode\\.(D|X)(.*)".r
-    val knownPrefix = Set("multnode.", "akka.", "MultiJvm.")
-    val akkaProperties =
+    val knownPrefix = Set("multinode.", "pekko.", "MultiJvm.")
+    val pekkoProperties =
       
System.getProperties.propertyNames.asInstanceOf[java.util.Enumeration[String]].asScala.toList.collect
 {
         case MultinodeJvmArgs(a, b) =>
           val value = System.getProperty("multinode." + a + b)
@@ -55,7 +55,7 @@ object MultiNode extends AutoPlugin {
         case key: String if knownPrefix.exists(pre => key.startsWith(pre)) => 
"-D" + key + "=" + System.getProperty(key)
       }
 
-    "-Xmx256m" :: akkaProperties ::: 
CliOptions.sbtLogNoFormat.ifTrue("-Dakka.test.nocolor=true").toList
+    "-Xmx256m" :: pekkoProperties ::: 
CliOptions.sbtLogNoFormat.ifTrue("-Dpekko.test.nocolor=true").toList
   }
 
   private val multiJvmSettings =
@@ -102,7 +102,7 @@ object MultiNodeScalaTest extends AutoPlugin {
   override lazy val projectSettings = Seq(
     MultiJvm / extraOptions := {
       val src = (MultiJvm / sourceDirectory).value
-      (name: String) => (src ** (name + 
".conf")).get.headOption.map("-Dakka.config=" + _.absolutePath).toSeq
+      (name: String) => (src ** (name + 
".conf")).get.headOption.map("-Dpekko.config=" + _.absolutePath).toSeq
     },
     MultiJvm / scalatestOptions := {
       Seq("-C", "org.scalatest.extra.QuietReporter")


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]


Reply via email to
diff --git 
a/http-core/src/test/scripts/autobahn-jenkins/step-5-server-tests-all.sh 
b/http-core/src/test/scripts/autobahn-jenkins/step-5-server-tests-all.sh
index f3394c89b..37198ac4b 100644
--- a/http-core/src/test/scripts/autobahn-jenkins/step-5-server-tests-all.sh
+++ b/http-core/src/test/scripts/autobahn-jenkins/step-5-server-tests-all.sh
@@ -1,16 +1,16 @@
 #!/usr/bin/env bash
 ### SERVER TESTS ###
 
 ## RUN AKKA WS-ECHO SERVER ##
 # sadly hardcoded here, we must do much more than just "run sbt", thus running 
manually
 SBT_JAR=/usr/share/sbt-launcher-packaging/bin/sbt-launch.jar # this jar is 
"sbt-latest-deb" (from the apt package)
-SBT_OPTS="-Dsbt.ivy.home=/localhome/jenkinsakka/.ivy2 
-Dsbt.override.repos=false"
+SBT_OPTS="-Dsbt.ivy.home=/localhome/jenkinspekko/.ivy2 
-Dsbt.override.repos=false"
 
 # warning, bash magic – the parens are important, they cause the background 
process to be executed in a sub shell
 # and only thanks to that, will it not be forced into [Stopped] state, as bash 
thinks sbt is awaiting on some input
 # and then decides to stop it (instead of keep it running). Keeping it in a 
sub shell, keeps it running.
-TEST_CLASS=akka.http.impl.engine.ws.WSServerAutobahnTest
-(java $SBT_OPTS -Dakka.ws-mode=sleep -Dakka.ws-host=127.0.0.1 -jar $SBT_JAR 
"pekko-http-core-experimental/test:run-main $TEST_CLASS" | tee output &)
+TEST_CLASS=org.apache.pekko.http.impl.engine.ws.WSServerAutobahnTest
+(java $SBT_OPTS -Dpekko.ws-mode=sleep -Dpekko.ws-host=127.0.0.1 -jar $SBT_JAR 
"pekko-http-core-experimental/test:run-main $TEST_CLASS" | tee output &)
 
 # because of the sub-shell $! is not reported, we need to find the PID some 
@@ -1,16 +1,16 @@
 ### SERVER TESTS ###
 
-## RUN AKKA WS-ECHO SERVER ##
+## RUN PEKKO WS-ECHO SERVER ##
 # sadly hardcoded here, we must do much more than just "run sbt", thus running 
manually
other way:
 SUB_PID=$(jps -mlV | grep $TEST_CLASS | awk '{print $1}') # the PID of JVM